@@ -15,40 +15,47 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * May, 2000. Implemented on FreeBSD 4.0R (Compaq Armada M700)
- *
-$Id: battstat.h,v 1.27 2005/01/13 13:17:07 bdejean Exp $
+ $Id: battstat.h 9983 2006-09-22 00:20:32Z ryanl $
  */
 
+#ifndef _battstat_h_
+#define _battstat_h_
+
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <panel-applet.h>
+#include <panel-applet-gconf.h>
+
 #define DEBUG 0
 
-#ifdef __FreeBSD__
-#define APMDEVICE	"/dev/apm"
-#endif /* __FreeBSD__ */
-
-#ifdef __OpenBSD__
-#define APMDEVICE       "/dev/apm"
-#endif /* __OpenBSD__ */
-
 #define PROGLEN 33.0
 
-enum {
-	APPLET_SHOW_NONE,
-	APPLET_SHOW_PERCENT,
-	APPLET_SHOW_TIME
-};
+/* I made these multipliers up
+ *  --davyd
+ */
+#define ORANGE_MULTIPLIER 1.5
+#define YELLOW_MULTIPLIER 2.5
 
 typedef enum
 {
-  BATTERY_HIGH     = 0,
-  BATTERY_LOW      = 1,
-  BATTERY_CRITICAL = 2,
-  BATTERY_CHARGING = 3
-} BatteryState;
+  APPLET_SHOW_NONE,
+  APPLET_SHOW_PERCENT,
+  APPLET_SHOW_TIME
+} AppletTextType;
+
+typedef enum
+{
+  STATUS_PIXMAP_BATTERY,
+  STATUS_PIXMAP_METER,
+  STATUS_PIXMAP_AC,
+  STATUS_PIXMAP_CHARGE,
+  STATUS_PIXMAP_WARNING,
+  STATUS_PIXMAP_NUM
+} StatusPixmapIndex;
 
 typedef struct
 {
-  BatteryState state;
   gboolean on_ac_power;
   gboolean charging;
   gboolean present;
@@ -77,91 +84,92 @@ typedef struct
 
 typedef struct _ProgressData {
   GtkWidget *applet;
-  GtkStyle *style;
-  GtkWidget *progdir_radio;
-  GtkWidget *radio_orient_horizont;
-  GtkWidget *radio_lay_batt_on;
-  GtkWidget *radio_lay_status_on;
+
+  /* these are used by properties.c */
+  GtkWidget *radio_ubuntu_battery;
+  GtkWidget *radio_traditional_battery;
   GtkWidget *radio_text_1;
   GtkWidget *radio_text_2;
   GtkWidget *check_text;
+  GtkWidget *lowbatt_toggle;
+  GtkWidget *full_toggle;
+  GtkWidget *hbox_ptr;
 
-  GtkTooltips *tip;
-
-  GtkWidget *about_dialog;
-  GtkDialog *prop_win;
-
-  GdkGC *pixgc;
-
-  GtkWidget *table;
-
-  GtkWidget *battery;
-  GtkWidget *status;
-  GtkWidget *percent;
-
-  gboolean colors_changed;
+  /* flags set from gconf or the properties dialog */
+  guint red_val;
+  guint orange_val;
+  guint yellow_val;
+  gboolean red_value_is_time;
   gboolean lowbattnotification;
   gboolean fullbattnot;
   gboolean beep;
   gboolean draintop;
   gboolean showstatus;
   gboolean showbattery;
-  int showtext;
+  AppletTextType showtext;
 
+  /* label changed type (% <-> h:mm) and must be refreshed */
+  gboolean refresh_label;
+
+  /* tooltip attached to 'applet' */
+  GtkTooltips *tip;
+
+  /* so we don't have to alloc/dealloc this every refresh */
+  GdkGC *pixgc;
+
+  /* the main table that contains the visual elements */
+  GtkWidget *table;
+
+  /* the visual elements */
+  GtkWidget *battery;
+  GtkWidget *status;
+  GtkWidget *percent;
+
+  /* dialog boxes that might be displayed */
+  GtkWidget *about_dialog;
+  GtkDialog *prop_win;
+  GtkWidget *battery_low_dialog;
+
+  /* text label inside the low battery dialog */
+  GtkLabel *battery_low_label;
+
+  /* our height/width as given to us by size_allocate */
   gint width, height;
+
+  /* should the battery meter be drawn horizontally? */
   gboolean horizont;
 
-  GtkWidget *suspend_entry;
-  char *suspend_cmd;
-  char *fontname;
-  guint red_val;
-  guint orange_val;
-  guint yellow_val;
-  int panelsize;
+  /* on a vertical or horizontal panel? (up/down/left/right) */
   PanelAppletOrient orienttype;
+
+  /* the current layout of the visual elements inside the table */
   LayoutConfiguration layout;
-  int pixtimer;
 
-  GtkWidget *lowbatt_toggle;
-  GtkWidget *full_toggle;
-  GtkWidget *lowbattnotificationdialog;
+  /* g_timeout source identifier */
+  int timeout_id;
+  int timeout;
 
-  /* last_* for the benefit of the timeout functions */
-  guint flash;
+  /* last_* for the benefit of the check_for_updates function */
   guint last_batt_life;
   guint last_acline_status;
-  guint last_batt_state;
-  guint last_pixmap_index;
+  StatusPixmapIndex last_pixmap_index;
   guint last_charging;
+  guint last_minutes;
+  gboolean last_present;
 } ProgressData;
 
-enum statusimagename {BATTERY,AC,FLASH,WARNING};
-
-GdkPixmap *statusimage[4];
-GdkBitmap *statusmask[4];
-
-extern char * battery_gray_xpm[];
-
+/* properties.c */
 void prop_cb (BonoboUIComponent *, ProgressData *, const char *);
-int prop_cancel (GtkWidget *, gpointer);
 
-void adj_value_changed_cb(GtkAdjustment *, gpointer);
-void simul_cb(GtkWidget *, gpointer);
-void helppref_cb(PanelApplet *, gpointer);
-gint check_for_updates(gpointer);
-void change_orient(PanelApplet *, PanelAppletOrient, ProgressData *);
-void destroy_applet( GtkWidget *, gpointer);
-void cleanup(PanelApplet *, int);
-void help_cb (BonoboUIComponent *, ProgressData *, const char *);
-void suspend_cb (BonoboUIComponent *, ProgressData *, const char *);
-void destroy_about (GtkWidget *, gpointer);
-void about_cb (BonoboUIComponent *, ProgressData *, const char *);
-void load_preferences(ProgressData *battstat);
+/* battstat_applet.c */
+void reconfigure_layout( ProgressData *battstat );
+void battstat_show_help( ProgressData *battstat, const char *section );
 
 /* power-management.c */
 const char *power_management_getinfo( BatteryStatus *status );
-const char *power_management_initialise( void );
+const char *power_management_initialise (int no_hal, void (*callback) (void));
 void power_management_cleanup( void );
+int power_management_using_hal( void );
 
 
-void reconfigure_layout( ProgressData *battstat );
+#endif /* _battstat_h_ */
